:mod:`zope.event` Documentation
===============================

This package provides a simple event system on which
application-specific event systems can be built.

Application code can generate events without being concerned about the
event-processing frameworks that might handle the events.

Events are objects that represent something happening in a system.
They are used to extend processing by providing processing plug
points.

Contents:

.. toctree::
   :maxdepth: 2

   usage
   theory
   api
   hacking

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
